@@ -1,10 +1,14 @@
 use std::convert::Infallible;
-use std::{fmt, io, error};
+use std::{error, fmt, io};
 
+/// Represents an error that can occur while using this library.
 #[derive(Debug)]
-pub enum Error<U=Infallible> {
+pub enum Error<U = Infallible> {
+    /// An [`io::Error`] occured either while reading or writing.
     Io(io::Error),
+    /// A merge error occured while trying to merge values.
     Merge(U),
+    /// An invalid [`crate::CompressionType`] has been encountered.
     InvalidCompressionType,
 }
 
@@ -28,10 +32,16 @@ impl<U: fmt::Display> fmt::Display for Error<U> {
     }
 }
 
-impl<U: fmt::Display + fmt::Debug> error::Error for Error<U> { }
+impl<U: fmt::Display + fmt::Debug> error::Error for Error<U> {}
 
 impl<U> From<io::Error> for Error<U> {
     fn from(err: io::Error) -> Error<U> {
         Error::Io(err)
     }
 }
+
+impl<U> From<Infallible> for Error<U> {
+    fn from(_err: Infallible) -> Error<U> {
+        unreachable!()
+    }
+}
